%{!?upstream_version: %global upstream_version %{version}%{?milestone}}
%if 0%{?fedora} >= 24
%global with_python3 1
%endif

%global pypi_name oslo.middleware
%global pkg_name oslo-middleware
%global common_desc \
The OpenStack Oslo Middleware library. \
Oslo middleware library includes components that can be injected into wsgi \
pipelines to intercept request/response flows. The base class can be \
enhanced with functionality like add/delete/modification of http headers \
and support for limiting size/connection etc.

%global common_desc2 \
Tests for the Oslo Middleware library.

Name:           python-oslo-middleware
Version:        3.36.0
Release:        1%{?dist}
Summary:        OpenStack Oslo Middleware library

License:        ASL 2.0
URL:            https://launchpad.net/oslo
Source0:        https://tarballs.openstack.org/%{pypi_name}/%{pypi_name}-%{upstream_version}.tar.gz
BuildArch:      noarch

BuildRequires:  python2-devel
BuildRequires:  python-pbr
# for docs build
BuildRequires:  git
BuildRequires:  python-oslo-config
BuildRequires:  python-oslo-context
BuildRequires:  python-oslo-i18n
BuildRequires:  python-oslo-utils
# Required for testing
BuildRequires:  python-fixtures
BuildRequires:  python-hacking
BuildRequires:  python-mock
BuildRequires:  python-oslotest
BuildRequires:  python-oslo-serialization
BuildRequires:  python-statsd
BuildRequires:  python-testtools
%if 0%{?fedora} > 0
BuildRequires:  python-webob
%else
BuildRequires:  python-webob
%endif
# Required to compile translation files
BuildRequires:  python-babel

Requires:       python-pbr
Requires:       python-debtcollector >= 1.2.0
Requires:       python-jinja2
Requires:       python-oslo-config >= 2:5.2.0
Requires:       python-oslo-context >= 2.19.2
Requires:       python-oslo-i18n >= 3.15.3
Requires:       python-oslo-utils >= 3.33.0
Requires:       python-six
Requires:       python-statsd
Requires:       python-stevedore >= 1.20.0
%if 0%{?fedora} > 0
Requires:       python-webob >= 1.7.1
%else
Requires:       python-webob >= 1.7.1
%endif
Requires:       python-%{pkg_name}-lang = %{version}-%{release}

%if 0%{?with_python3}
%package -n python3-%{pkg_name}
Summary:        OpenStack Oslo Middleware library
%{?python_provide:%python_provide python3-%{pkg_name}}

BuildRequires:  python3-devel
BuildRequires:  python3-pbr
# for docs build
BuildRequires:  python3-oslo-config
BuildRequires:  python3-oslo-context
BuildRequires:  python3-oslo-i18n
# Required for testing
BuildRequires:  python3-fixtures
BuildRequires:  python3-hacking
BuildRequires:  python3-mock
BuildRequires:  python3-oslotest
BuildRequires:  python3-oslo-serialization
BuildRequires:  python3-statsd
BuildRequires:  python3-testtools
BuildRequires:  python3-webob

Requires:       python3-pbr
Requires:       python3-debtcollector >= 1.2.0
Requires:       python3-jinja2
Requires:       python3-oslo-config >= 2:5.2.0
Requires:       python3-oslo-context >= 2.19.2
Requires:       python3-oslo-i18n >= 3.15.3
Requires:       python3-oslo-utils >= 3.33.0
Requires:       python3-six
Requires:       python3-statsd
Requires:       python3-stevedore >= 1.20.0
Requires:       python3-webob >= 1.7.1
Requires:       python-%{pkg_name}-lang = %{version}-%{release}

%description -n python3-%{pkg_name}
%{common_desc}

%package -n python3-%{pkg_name}-tests
Summary:    Tests for the Oslo Middleware library

Requires:  python3-%{pkg_name} = %{version}-%{release}
Requires:  python3-fixtures
Requires:  python3-hacking
Requires:  python3-mock
Requires:  python3-oslotest
Requires:  python3-testtools

%description -n python3-%{pkg_name}-tests
%{common_desc2}

%endif

%package doc
Summary:    Documentation for the Oslo Middleware library
Group:      Documentation

BuildRequires:  python-sphinx
BuildRequires:  python-openstackdocstheme

%description doc
Documentation for the Oslo Middleware library.

%package -n python-%{pkg_name}-tests
Summary:    Tests for the Oslo Middleware library

Requires:  python-%{pkg_name} = %{version}-%{release}
Requires:  python-fixtures
Requires:  python-hacking
Requires:  python-mock
Requires:  python-oslotest
Requires:  python-testtools

%description -n python-%{pkg_name}-tests
%{common_desc2}

%package  -n python-%{pkg_name}-lang
Summary:   Translation files for Oslo middleware library

%description -n python-%{pkg_name}-lang
Translation files for Oslo middleware library

%description
%{common_desc}

%prep
%autosetup -n %{pypi_name}-%{upstream_version} -S git
# Let RPM handle the dependencies
rm -rf {test-,}requirements.txt

%build
%py2_build

%if 0%{?with_python3}
%py3_build
%endif

# generate html docs
python setup.py build_sphinx -b html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}
# Generate i18n files
%{__python} setup.py compile_catalog -d build/lib/oslo_middleware/locale

%install
%py2_install

%if 0%{?with_python3}
%py3_install
%endif

# Install i18n .mo files (.po and .pot are not required)
install -d -m 755 %{buildroot}%{_datadir}
rm -f %{buildroot}%{python_sitelib}/oslo_middleware/locale/*/LC_*/oslo_middleware*po
rm -f %{buildroot}%{python_sitelib}/oslo_middleware/locale/*pot
mv %{buildroot}%{python_sitelib}/oslo_middleware/locale %{buildroot}%{_datadir}/locale
%if 0%{?with_python3}
rm -rf %{buildroot}%{python3_sitelib}/oslo_middleware/locale
%endif

# Find language files
%find_lang oslo_middleware --all-name

%check
%{__python} setup.py test
%if 0%{?with_python3}
rm -rf .testrepository
%{__python3} setup.py test
%endif

%files -n python-%{pkg_name}
%license LICENSE
%doc README.rst
%{python_sitelib}/oslo_middleware
%{python_sitelib}/*.egg-info
%exclude %{python_sitelib}/oslo_middleware/tests/

%if 0%{?with_python3}
%files -n python3-%{pkg_name}
%license LICENSE
%doc README.rst
%{python3_sitelib}/oslo_middleware
%{python3_sitelib}/*.egg-info

%files -n python3-%{pkg_name}-tests
%{python3_sitelib}/oslo_middleware/tests/
%endif

%files doc
%license LICENSE
%doc doc/build/html

%files -n python-%{pkg_name}-tests
%{python2_sitelib}/oslo_middleware/tests/

%files -n python-%{pkg_name}-lang -f oslo_middleware.lang
%license LICENSE

%changelog
* Mon Aug 06 2018 RDO <dev@lists.rdoproject.org> 3.36.0-1
- Update to 3.36.0

